# Axon Synthesis

A package to synthesize artificial axons


## Installation

TODO: Replace this text by proper installation instructions.


## Examples

TODO: Provide here some examples on how this software can be used.


## Funding & Acknowledgment

The development of this software was supported by funding to the Blue Brain Project, a research
center of the École polytechnique fédérale de Lausanne (EPFL), from the Swiss government’s ETH
Board of the Swiss Federal Institutes of Technology.

For license and authors, see `LICENSE.txt` and `AUTHORS.md` respectively.

Copyright © 2022-2023 Blue Brain Project/EPFL
